﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using Infragistics.Windows;
using Infragistics.Windows.DataPresenter;
using Infragistics.Controls.Menus;
using Infragistics.Windows.DataPresenter.ExcelExporter;
using Infragistics.Documents.Excel;


namespace MyDataGrid
{
    public class AwrdsDataGrid : XamDataGrid
    {
        Label lblFilteredItems = new Label();
        private ContextMenuManager contextMenuManager1 = new ContextMenuManager();
        private XamContextMenu xamContextMenu1 = new XamContextMenu();
        private XamMenuItem menuItemCopy = new XamMenuItem { Header = "Copy" };
        private XamMenuItem menuItemExportToExcel = new XamMenuItem { Header = "Export To Excel" };
        private XamDataGrid myDataGrid = new XamDataGrid();

        public AwrdsDataGrid()
        {
            this.Loaded += new RoutedEventHandler(myGrid_Loaded);
            this.RecordsInViewChanged += new EventHandler<Infragistics.Windows.DataPresenter.Events.RecordsInViewChangedEventArgs>(myGrid_RecordsInViewChanged);
            this.menuItemCopy.Click += new EventHandler(menuItemCopy_Click);
            this.menuItemExportToExcel.Click += new EventHandler(menuItemExportToExcel_Click);
            Infragistics.Controls.Menus.ContextMenuService.SetManager(this, contextMenuManager1);
            contextMenuManager1.ContextMenu = xamContextMenu1;
            xamContextMenu1.Items.Add(menuItemCopy);
            xamContextMenu1.Items.Add(menuItemExportToExcel);
        }
        
        #region Events

        void myGrid_Loaded(object sender, RoutedEventArgs e)
        {
            myDataGrid = sender as XamDataGrid;
            Grid grid = Utilities.GetDescendantFromType(myDataGrid, typeof(Grid), false) as Grid;

            if (grid != null && myDataGrid.Records.Count > 0)
            {
                grid.RowDefinitions.Add(new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) });

                Grid DynamicGrid = new Grid();
                DynamicGrid.HorizontalAlignment = HorizontalAlignment.Stretch;
                DynamicGrid.VerticalAlignment = VerticalAlignment.Top;

                RowDefinition gridRow1 = new RowDefinition { Height = new GridLength(1, GridUnitType.Star) };
                RowDefinition gridRow2 = new RowDefinition { Height = new GridLength(1, GridUnitType.Auto) };
                DynamicGrid.RowDefinitions.Add(gridRow1);
                DynamicGrid.RowDefinitions.Add(gridRow2);

                lblFilteredItems.VerticalAlignment = VerticalAlignment.Bottom;
                lblFilteredItems.HorizontalAlignment = HorizontalAlignment.Left;
                Grid.SetRow(lblFilteredItems, 0);
                DynamicGrid.Children.Add(lblFilteredItems);

                SearchBar searchBar = new SearchBar();
                Grid.SetRow(searchBar, 1);
                DynamicGrid.Children.Add(searchBar);

                grid.Children.Add(DynamicGrid);

            }
            else
            {
                grid.RowDefinitions.Add(new RowDefinition { Height = new GridLength(1, GridUnitType.Star) });
                lblFilteredItems.Visibility = Visibility.Visible;
                lblFilteredItems.Content = "Please Select A Search Criteria";
                lblFilteredItems.VerticalAlignment = VerticalAlignment.Bottom;
                lblFilteredItems.HorizontalAlignment = HorizontalAlignment.Center;
                Grid.SetRow(lblFilteredItems, 0);
                grid.Children.Add(lblFilteredItems);
            }

        }

        void myGrid_RecordsInViewChanged(object sender, Infragistics.Windows.DataPresenter.Events.RecordsInViewChangedEventArgs e)
        {
            string results = string.Empty;
            XamDataGrid myDataGrid = sender as XamDataGrid;
            Grid grid = Utilities.GetDescendantFromType(myDataGrid, typeof(Grid), false) as Grid;

            if (myDataGrid.Records.Count > 0)
            {
                foreach (RecordFilter filter in myDataGrid.FieldLayouts[0].RecordFilters)
                {
                    if (filter.Conditions.Count > 0)
                    {
                        results += filter.FieldName + ",";
                    }
                }
                lblFilteredItems.Content = "Filtered Fields: " + results;
                lblFilteredItems.VerticalAlignment = VerticalAlignment.Bottom;
                lblFilteredItems.HorizontalAlignment = HorizontalAlignment.Left;
            }
        }

        void menuItemExportToExcel_Click(object sender, EventArgs e)
        {

            // Establish the file name to use for the export.
            string fileName = "Workbook1.xlsx";

            try
            {
                // Get the instance of the DataPresenterExcelExporter defined in the Page's resources and call its Export
                // method passing in the XamDataGrid we want to export, the name of the file we would like
                // to export to and the format of the Workbook we want to Exporter to create.
                DataPresenterExcelExporter exporter = (DataPresenterExcelExporter)this.TryFindResource("Exporter");
                ExportOptions options = new ExportOptions();
                options.FileLimitBehaviour = FileLimitBehaviour.ThrowException;
                exporter.Export(myDataGrid, fileName, WorkbookFormat.Excel2007, options);
                System.Diagnostics.Process p = new System.Diagnostics.Process();
                p.StartInfo.FileName = fileName;
                p.Start();
            }
            catch (Exception ex)
            {
                // It's possible that the exporter does not have permission to write the file, so it's generally
                // a good idea to account for this possibility.
                MessageBox.Show(ex.Message);

                return;
            }
        }

        void menuItemCopy_Click(object sender, EventArgs e)
        {
            myDataGrid.ExecuteCommand(DataPresenterCommands.Copy);
        }

        #endregion
    }
}
